// types/post.ts
export interface Post {
    id: number
    title: string
    content?: string
    category: string
    views: number
    likes: number
    comments?: number
    createdAt: string
    updatedAt?: string
    status: 'published' | 'draft'
    author?: {
        id: number
        username: string
        avatar?: string
    }
}

export interface PostListParams {
    page: number
    pageSize: number
    title?: string
    category?: string
    status?: string
    sortBy?: 'createdAt' | 'views' | 'likes'
    sortOrder?: 'asc' | 'desc'
}

export interface PostListResponse {
    data: Post[]
    total: number
    page: number
    pageSize: number
    totalPages: number
}

export interface FilterForm {
    title: string
    category: string
    status?: string
}

export interface Pagination {
    currentPage: number
    pageSize: number
    total: number
}

export interface Stats {
    totalPosts: number
    totalViews: number
    totalLikes: number
    totalComments: number
    avgViews: number
    avgLikes: number
}

export interface DeleteDialog {
    visible: boolean
    loading: boolean
    type: 'single' | 'batch'
    post?: Post
}

// types/api.ts
export interface ApiResponse<T = any> {
    code: number
    message: string
    data: T
    timestamp: number
}

export interface ApiError {
    code: number
    message: string
    details?: any
}

// types/category.ts
export interface Category {
    id: string
    name: string
    description?: string
    color?: string
    icon?: string
}

export const CATEGORIES: Category[] = [
    { id: 'tech', name: '技术讨论', color: 'primary', icon: 'Monitor' },
    { id: 'life', name: '生活随笔', color: 'success', icon: 'Coffee' },
    { id: 'study', name: '学习分享', color: 'warning', icon: 'Reading' },
    { id: 'qa', name: '问答求助', color: 'info', icon: 'QuestionFilled' }
]

// types/user.ts
export interface User {
    id: number
    username: string
    email: string
    avatar?: string
    role: 'admin' | 'user'
    createdAt: string
    profile?: {
        nickname?: string
        bio?: string
        location?: string
        website?: string
    }
}

